@@ -1,6 +1,9 @@
 package tui
 
 import (
+	"fmt"
+	"os"
+
 	"github.com/dundee/gdu/v5/pkg/analyze"
 	"github.com/gdamore/tcell/v2"
 )
@@ -29,9 +32,26 @@ func (ui *UI) keyPressed(key *tcell.EventKey) *tcell.EventKey {
 	}
 
 	switch key.Rune() {
+	case 'Q':
+		ui.app.Stop()
+		fmt.Fprintf(ui.output, "%s\n", ui.currentDirPath)
+		return nil
 	case 'q':
 		ui.app.Stop()
 		return nil
+	case 'b':
+		ui.app.Stop()
+		if err := os.Chdir(ui.currentDirPath); err != nil {
+			panic(err)
+		}
+		shell, ok := os.LookupEnv("SHELL")
+		if !ok {
+			shell = "/bin/bash"
+		}
+		if err := ui.exec(shell, nil, os.Environ()); err != nil {
+			panic(err)
+		}
+		return nil
 	case '?':
 		ui.showHelp()
 	}
@@ -84,6 +104,13 @@ func (ui *UI) keyPressed(key *tcell.EventKey) *tcell.EventKey {
 			ui.showDir()
 			ui.table.Select(row, column)
 		}
+	case 'm':
+		ui.showMtime = !ui.showMtime
+		if ui.currentDir != nil {
+			row, column := ui.table.GetSelection()
+			ui.showDir()
+			ui.table.Select(row, column)
+		}
 	case 'r':
 		if ui.currentDir != nil {
 			ui.rescanDir()
@@ -94,6 +121,8 @@ func (ui *UI) keyPressed(key *tcell.EventKey) *tcell.EventKey {
 		ui.setSorting("itemCount")
 	case 'n':
 		ui.setSorting("name")
+	case 'M':
+		ui.setSorting("mtime")
 	case '/':
 		ui.showFilterInput()
 	default:
