@@ -2,8 +2,10 @@ package tui
 
 import (
 	"fmt"
+	"io"
 	"sort"
 	"strings"
+	"syscall"
 	"time"
 
 	log "github.com/sirupsen/logrus"
@@ -25,7 +27,10 @@ const helpText = `    [::b]up/down, k/j    [white:black:-]Move cursor up/down
                [::b]/    [white:black:-]Search items by name
                [::b]a    [white:black:-]Toggle between showing disk usage and apparent size
                [::b]c    [white:black:-]Show/hide file count
+               [::b]m    [white:black:-]Show/hide latest mtime
+               [::b]b    [white:black:-]Spawn shell in current directory
                [::b]q    [white:black:-]Quit gdu
+               [::b]Q    [white:black:-]Quit gdu and print current directory path
 
 Item under cursor:
                [::b]d    [white:black:-]Delete file or directory
@@ -37,12 +42,14 @@ Sort by (twice toggles asc/desc):
                [::b]n    [white:black:-]Sort by name (asc/desc)
                [::b]s    [white:black:-]Sort by size (asc/desc)
                [::b]C    [white:black:-]Sort by file count (asc/desc)
-`
+               [::b]M    [white:black:-]Sort by mtime (asc/desc)`
 
 // UI struct
 type UI struct {
 	*common.UI
 	app             common.TermApplication
+	screen          tcell.Screen
+	output          io.Writer
 	header          *tview.TextView
 	footer          *tview.Flex
 	footerLabel     *tview.TextView
@@ -59,6 +66,7 @@ type UI struct {
 	currentDirPath  string
 	askBeforeDelete bool
 	showItemCount   bool
+	showMtime       bool
 	filtering       bool
 	filterValue     string
 	sortBy          string
@@ -66,22 +74,27 @@ type UI struct {
 	done            chan struct{}
 	remover         func(*analyze.Dir, analyze.Item) error
 	emptier         func(*analyze.Dir, analyze.Item) error
+	exec            func(argv0 string, argv []string, envv []string) error
 }
 
 // CreateUI creates the whole UI app
-func CreateUI(app common.TermApplication, useColors bool, showApparentSize bool) *UI {
+func CreateUI(app common.TermApplication, screen tcell.Screen, output io.Writer, useColors bool, showApparentSize bool) *UI {
 	ui := &UI{
 		UI: &common.UI{
 			UseColors:        useColors,
 			ShowApparentSize: showApparentSize,
 			Analyzer:         analyze.CreateAnalyzer(),
 		},
+		app:             app,
+		screen:          screen,
+		output:          output,
 		askBeforeDelete: true,
 		showItemCount:   false,
 		sortBy:          "size",
 		sortOrder:       "desc",
 		remover:         analyze.RemoveItemFromDir,
 		emptier:         analyze.EmptyFileFromDir,
+		exec:            syscall.Exec,
 	}
 
 	app.SetBeforeDrawFunc(func(screen tcell.Screen) bool {
@@ -89,7 +102,6 @@ func CreateUI(app common.TermApplication, useColors bool, showApparentSize bool)
 		return false
 	})
 
-	ui.app = app
 	ui.app.SetInputCapture(ui.keyPressed)
 
 	var textColor, textBgColor tcell.Color
@@ -262,6 +274,13 @@ func (ui *UI) sortItems() {
 			sort.Sort(sort.Reverse(analyze.ByName(ui.currentDir.Files)))
 		}
 	}
+	if ui.sortBy == "mtime" {
+		if ui.sortOrder == "desc" {
+			sort.Sort(analyze.ByMtime(ui.currentDir.Files))
+		} else {
+			sort.Sort(sort.Reverse(analyze.ByMtime(ui.currentDir.Files)))
+		}
+	}
 }
 
 func (ui *UI) fileItemSelected(row, column int) {
@@ -403,6 +422,7 @@ func (ui *UI) showHelp() {
 	text.SetBorder(true).SetBorderPadding(2, 2, 2, 2)
 	text.SetBorderColor(tcell.ColorDefault)
 	text.SetTitle(" gdu help ")
+	text.SetScrollable(true)
 
 	if ui.UseColors {
 		text.SetText(
@@ -416,14 +436,21 @@ func (ui *UI) showHelp() {
 		text.SetText(helpText)
 	}
 
+	maxHeight := strings.Count(helpText, "\n") + 7
+	_, height := ui.screen.Size()
+	if height > maxHeight {
+		height = maxHeight
+	}
+
 	flex := tview.NewFlex().
 		AddItem(nil, 0, 1, false).
 		AddItem(tview.NewFlex().SetDirection(tview.FlexRow).
 			AddItem(nil, 0, 1, false).
-			AddItem(text, 27, 1, false).
+			AddItem(text, height, 1, false).
 			AddItem(nil, 0, 1, false), 80, 1, false).
 		AddItem(nil, 0, 1, false)
 
 	ui.help = flex
 	ui.pages.AddPage("help", flex, true, true)
+	ui.app.SetFocus(text)
 }
